# coding=utf-8
# Copyright 2026 XRTM Team. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

r"""
Sentinel Protocol: Dynamic Forecasting Drivers.

This module provides interfaces and implementations for tracking forecast
evolution over time, enabling "living forecasts" that update as new
information becomes available.
"""

from forecast.kit.sentinel.base import SentinelDriver, TriggerRules
from forecast.kit.sentinel.polling import PollingDriver

__all__ = [
    "SentinelDriver",
    "TriggerRules",
    "PollingDriver",
]
